summaryrefslogtreecommitdiffstats
path: root/chalk/core/kis_paint_device.h
diff options
context:
space:
mode:
Diffstat (limited to 'chalk/core/kis_paint_device.h')
-rw-r--r--chalk/core/kis_paint_device.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/chalk/core/kis_paint_device.h b/chalk/core/kis_paint_device.h
index 6e804afe6..6c8d7331a 100644
--- a/chalk/core/kis_paint_device.h
+++ b/chalk/core/kis_paint_device.h
@@ -90,13 +90,13 @@ public:
/**
* Create a new paint device with the specified colorspace. The
* tqparentLayer will be notified of changes to this paint device.
*
* @param tqparentLayer the layer that contains this paint device.
* @param colorSpace the colorspace of this paint device
* @param name for debugging purposes
*/
- KisPaintDevice(KisLayer *tqparentLayer, KisColorSpace * colorSpace, const char * name = 0);
+ KisPaintDevice(KisLayer *parentLayer, KisColorSpace * colorSpace, const char * name = 0);
KisPaintDevice(const KisPaintDevice& rhs);
virtual ~KisPaintDevice();
@@ -386,7 +386,7 @@ public:
/**
* Return the image that contains this paint device, or 0 if it is not
* part of an image. This is the same as calling tqparentLayer()->image().
*/
KisImage *image() const;
@@ -394,13 +394,13 @@ public:
* Returns the KisLayer that contains this paint device, or 0 if this is not
* part of a layer.
*/
- KisLayer *tqparentLayer() const;
+ KisLayer *parentLayer() const;
/**
* Set the KisLayer that contains this paint device, or 0 if this is not
* part of a layer.
*/
- void setParentLayer(KisLayer *tqparentLayer);
+ void setParentLayer(KisLayer *parentLayer);
/**
* Add the specified rect top the tqparent layer (if present)
@@ -90,13 +90,13 @@ public:
/**
* Create a new paint device with the specified colorspace. The
- * tqparentLayer will be notified of changes to this paint device.
+ * parentLayer will be notified of changes to this paint device.
*
@@ -90,13 +90,13 @@ public:
*
- * @param tqparentLayer the layer that contains this paint device.
+ * @param parentLayer the layer that contains this paint device.
* @param colorSpace the colorspace of this paint device
* @param name for debugging purposes
@@ -386,7 +386,7 @@ public:
/**
* Return the image that contains this paint device, or 0 if it is not
- * part of an image. This is the same as calling tqparentLayer()->image().
+ * part of an image. This is the same as calling parentLayer()->image().
*/
KisImage *image() const;